#include "SimpleSoccer.h"
#include "Events/EventRouter.h"
#include "Events/VisionObjectEvent.h"
#include "Shared/WorldState.h"
#include "Motion/HeadPointerMC.h"
#include "Motion/WalkMC.h"
#include "Shared/WMclass.h"
#include "Shared/ProjectInterface.h"

//! Converts degrees to radians
inline double DtoR(double deg) { return (deg/180.0*M_PI); }



void SimpleSoccer::DoStart() {

	BehaviorBase::DoStart();

	erouter->addListener(this, EventBase::buttonEGID);

	//INITIALIZE VARS
	//PlayerType... default to Attacker
	player_type = ATTACKER_ID;
	desired_area = ATTACKER_DESIRED_AREA;
	//previous Area... used to track how close the ball is... default to far away
	previous_area = 999;
	
	//subState.. default to paused.
	subState = PLAY_PAUSED;
	currGState = INITIAL;
	//prior_mode = 999;
	//Timer off
	isTimerOn = false;
	isColorSet = true;
	cout << "Team color set to blue" << endl;
	isPosSet = false;
	tColor = BLUE;
	//timer Count = 0
	time_in_state = 0;
	//motion_waiting = false;

	//initialize area and position of goalie
	area1 = 0;
	horz1 = 0;
	vert1 = 0;
	area0 = 0;
	horz0 = 0;
	vert0 = 0;
	cur_time = 0.0;
	see_time = 0.0;
	isPosSet = false;

	//load sounds so that we can play them
	sndman->LoadFile("SoccerPr.wav");
	sndman->LoadFile("GoalieOn.wav");
	sndman->LoadFile("ForwardS.wav");
	sndman->LoadFile("ImGonnaS.wav");
	sndman->LoadFile("whimper.wav");

	//prepare motion manager to move head and walk
	headpointer_id = motman->addPersistentMotion(SharedObject<HeadPointerMC>());
	walker_id = motman->addPersistentMotion(SharedObject<WalkMC>());
	leds_mc->cycle(RobotInfo::ModeGreenLEDMask, 1000, 100.0);			//this will cause his back to flash blue
	leds_mc->cycle(RobotInfo::ModeRedLEDMask, 1000, 100.0);
	leds_id = motman->addPersistentMotion(leds_mc);

	//listen for events from vision (ID ball) and from buttons (switch player type/pause)
	erouter->addListener(this,EventBase::visObjEGID,ProjectInterface::visOrangeBallSID);
	erouter->addListener(this,EventBase::visObjEGID,ProjectInterface::visYellowGoalSID);
	erouter->addListener(this,EventBase::visObjEGID,ProjectInterface::visBlueBlob);
	erouter->addListener(this,EventBase::visObjEGID,ProjectInterface::visPinkBallSID);
	erouter->addListener(this,EventBase::buttonEGID, HeadFrButOffset);
	erouter->addListener(this,EventBase::buttonEGID, MiddleBackButOffset);
	erouter->addListener(this,EventBase::buttonEGID, BackButOffset);
	erouter->addListener(this,EventBase::buttonEGID, FrontBackButOffset);
	erouter->addListener(this,EventBase::buttonEGID, ChinButOffset);
	erouter->addListener(this,EventBase::sensorEGID, ChestIRFrameOffset);
	
	
	//1000 every second
	erouter->addTimer(this,1000,1000,true);
	erouter->addTimer(this,1111,500,true); //create a new timer, ID=1111, every 500ms, repeat=true
	time_in_state = 0;
	isBtnPressed = false;

	//create a new worldmap
	//pWorld = new WorldMap;

	HeadPointerMC * headpointer = (HeadPointerMC*)motman->checkoutMotion(headpointer_id);
	headpointer->setJoints(0,0,0);
	motman->checkinMotion(headpointer_id);
	
}

void SimpleSoccer::DoStop() {
	currGState = FINAL;
	erouter->removeListener(this);
	erouter->removeTimer(this);
	motman->removeMotion(headpointer_id);
	motman->removeMotion(walker_id);
	motman->removeMotion(leds_id);
	sndman->ReleaseFile("SoccerPr.wav");
	sndman->ReleaseFile("GoalieOn.wav");
	sndman->ReleaseFile("ImGonnaS.wav");
	sndman->ReleaseFile("ForwardS.wav");
	sndman->ReleaseFile("whimper.wav");
	BehaviorBase::DoStop();
	//delete pWorld;
}

//do something when an event is raised
//this could be cleaned up event-wise (only use a timer when out of view)
//###########################################################
//	Process the event
//###########################################################
void SimpleSoccer::processEvent(const EventBase& event) {
	

	//this is where we will process state transitions for the time being
	//there are only a few main states that we will need to worry about: initialize, ready, set, playing, penalized, final
	//state flow      init->ready->set->playing<->penalized->initial
	//final from anywhere


	float x,y,z;
	float distance;

	if(event.getGeneratorID()==EventBase::sensorEGID)		//this is just a sample conditonal to try and catch IR values
	{
		cout << "Possible sensor information\n";
		cout << "Magintude:" << event.getMagnitude() << endl;
	}
	
	if(event.getGeneratorID()==EventBase::timerEGID)
	{

		if(event.getSourceID()==1000)	//timer 1000 (this is the timer used for the attacker
		{
			time_in_state++;
		}
		else if(event.getSourceID() ==1111)		
		{
			if ( player_type != GOALIE_ID)				//this timer is only used for the goalie...return otherwise
				return;
		}
		

		if(currGState != PLAYING)		//this timer is only used for the playing state
			return;
	}

	if(event.getSourceID()==ProjectInterface::visPinkBallSID)
	{
		
		if(currGState != PLAYING && currGState != SET)			//these are the only 2 states where we will want to look for the ball
			return;												//this will reduce a lot of output spam
	}

	//if the event is not a timer event:
	if (INITIAL == currGState)
	{
	
		//check for an event that can move us to the set state
		subState = PLAY_PAUSED;			//aibo's play state
		cout << "The current state is Initialize" << endl;
	
		if(event.getTypeID() == EventBase::activateETID)	//this helps reduce spamming / double function calls
		{
			isBtnPressed = true;
			cout << "Chin button pressed\n";
		}
		
		if(event.getTypeID() == EventBase::deactivateETID)	//check first to see if it is a deactivation event (this is the only thing we process
		{
			switch(event.getSourceID())		//back switchs to mark as goalie/attacker/defender or head button for state transition
				{
					case HeadFrButOffset:				//head button pressed ...move to next state
						
						//head button has been pressed (by induction) and released (by observation)
						//change the state
						cout << "Head button released @ Time: " << time_in_state << endl;
						if( isPosSet && isBtnPressed )			//make sure that we qualify to continue
						{
							currGState = READY;
							time_in_state =0;						//reset counter since moving to new state
							isBtnPressed = false;
							leds_mc->cycle(RobotInfo::ModeBlueLEDMask, 1000, 100.0);
							leds_mc->set(RobotInfo::ModeGreenLEDMask, 0);			//this will make the green ear LEDs stop flashing
							leds_mc->set(RobotInfo::ModeRedLEDMask, 0);
						}
						
						break;
						
					case FrontBackButOffset:						//set the ID to attacker
						if(isPosSet == false){
						player_type = ATTACKER_ID;
						desired_area = ATTACKER_DESIRED_AREA;
						isPosSet = true;
						cout << "Attacker Set!" << endl;
						sndman->PlayFile("ForwardS.wav");
						}
						break;
					case MiddleBackButOffset:						//set the ID to Defender
						if(isPosSet == false) {
						player_type = DEFENDER_ID;
						desired_area = ATTACKER_DESIRED_AREA;
						isPosSet = true;
						cout << "Defender Set!" << endl;
						}
						break;
					case RearBackButOffset:							//set the ID to Goalie
						if(isPosSet == false) {
						player_type = GOALIE_ID;
						desired_area = GOALIE_DESIRED_AREA;
						isPosSet = true;
						cout << "Goalie Set!" << endl;
						sndman->PlayFile("GoalieOn.wav");
						}
						break;
					case ChinButOffset:
						if(isBtnPressed)				//helps prevent double tapping
						{
							isBtnPressed = false;
							if (tColor == BLUE)
							{
								tColor = RED;
								//change the LED color to RED
								//motman->removeMotion(leds_id);
								//MMAccessor<LedMC> leds_acc(leds_id);
								leds_mc->set(RobotInfo::TlBluLEDMask, 0);
								leds_mc->set(RobotInfo::TlRedLEDMask, 100);
								cout << "Team color is now red\n";
							}
							else
							{					
								tColor = BLUE;
								//MMAccessor<LedMC> leds_acc(leds_id);
                                
								leds_mc->set(RobotInfo::TlBluLEDMask, 100);
								leds_mc->set(RobotInfo::TlRedLEDMask, 0);
								cout << "Team Color is now blue\n";
							}
						}

			}; //end switch
		}
		return;
				
	} //endif INITIAL == currGState

	else if (READY == currGState)
	{
		
			
		cout << "The current state is READY" << endl;
		//if robot moves to position wait
		//otherwise press the head to move to set state
		if(event.getSourceID() == HeadFrButOffset)
		{
			if(EventBase::activateETID == event.getTypeID())				//this will ensure that a pressed button will not carry between states
				isBtnPressed = true;
			else if(EventBase::deactivateETID == event.getTypeID() && isBtnPressed)
			{
				cout << "Head button released! @ Time: " << time_in_state << endl;
				currGState = SET;
				time_in_state = 0;
				isBtnPressed = false;
				SharedObject<MediumMotionSequenceMC>  p("/ms/data/motion/pounce.pos");
				motman->addPrunableMotion(p);
				leds_mc->set(RobotInfo::ModeBlueLEDMask, 0);
				leds_mc->cycle(RobotInfo::ModeBlueLEDMask, 1000, 100.0);
				leds_mc->cycle(RobotInfo::ModeRedLEDMask, 1000, 100.0);
		
			}
		}

		if(event.getSourceID() == RearBackButOffset)			//used for debugging how the IR sensor works
		{
			float distance;
			//get the current distance from the IR sensor
			distance = state->sensors[ChestIRDistOffset];
			cout<< "distance: " << distance << endl;
		}
		return;

	}
	else if(SET == currGState )
	{
		
		cout << "The current state is SET" << endl;
		//make all of the face LEDs light up to signify that we are in the set state and ready to play
		leds_mc->flash(RobotInfo::FaceLEDMask, 100);
		
		//an example of this state is when the dog is sitting, waiting for kickoff

		//check for events (i.e. button press) that will move us into the playing state
		if( event.getSourceID() == HeadFrButOffset)
		{
			if(EventBase::activateETID == event.getTypeID())
			{
				isBtnPressed = true;
			}
			else if(event.getTypeID() == EventBase::deactivateETID && isBtnPressed)
			{
				time_in_state = 0;			//start the timer over to measure how long btn pressed
				isBtnPressed = false;		
				//move to state playing (end of penalty)
				cout << "Head button pressed! @ Time: " << time_in_state << endl;
				currGState = PLAYING;
				subState = PLAY_PLAY;					//playing  set to play
				leds_mc->set(RobotInfo::ModeBlueLEDMask, 0);
				leds_mc->set(RobotInfo::ModeRedLEDMask, 0);
				leds_mc->cycle(RobotInfo::ModeGreenLEDMask, 1000, 100.0); 
			}
		}

		//the dog should look for the ball while he is in this state

		else if (event.getSourceID()==ProjectInterface::visPinkBallSID)  //visOrangeBallSID)
		{	
			//ball is seen


		}
		else //if the ball isnot seen and the head button is not pressed
		{
			//call the function to pan the dog's head

		}

		return;
	}
	else if (PLAYING == currGState)
	{
		
		//cout << "The current state is PLAYING" << endl;
						
		//first, check to see if any of the back buttons are pressed to mark a penalty
		if( MiddleBackButOffset == event.getSourceID() || BackButOffset == event.getSourceID() || FrontBackButOffset ==  event.getSourceID() )
		{
		
			cout << "One of the back buttons was pressed and/or released @ Time: " << time_in_state << endl;
			
			//head less than 3 sec to move back to playing...more than 3 = initial state
			cout << "Head button pressed!" << endl;
			currGState = PENALIZED;
			subState = PLAY_PAUSED;
			leds_mc->set(RobotInfo::ModeGreenLEDMask, 0);
			leds_mc->cycle(RobotInfo::ModeRedLEDMask, 1000, 100.0); 

			//make sure that he stops moving
			WalkMC * walker = (WalkMC*)motman->checkoutMotion(walker_id);
			walker->setTargetVelocity(0,0,0);		
			motman->checkinMotion(walker_id);
			HeadPointerMC * headpointer= (HeadPointerMC*)motman->checkoutMotion(headpointer_id);
			headpointer->setJoints(DtoR(-60),0,DtoR(35));					//make AIBO drop his head to signify that he is penalized
			motman->checkinMotion(headpointer_id);
			cout<<"Stop Walk, Head Up"<<endl;
			time_in_state =0;
			return;
		}

		if( player_type == GOALIE_ID)
        {
			if( event.getSourceID()==ProjectInterface::visOrangeBallSID)
			{

				//orange ball event, record position and area
				horz1 = static_cast<const VisionObjectEvent*>(&event)->getCenterX();
				vert1 = static_cast<const VisionObjectEvent*>(&event)->getCenterY();
				area1 = static_cast<const VisionObjectEvent*>(&event)->getArea();

				if(area1 > 0.001)
					see_time = cur_time;

				double tilt=state->outputs[HeadOffset+TiltOffset]-vert1*M_PI/7.5;
				double pan=state->outputs[HeadOffset+PanOffset]-horz1*M_PI/6;
				if(tilt<DtoR(-20))
					tilt=DtoR(-20);
				if(tilt>DtoR(40))
					tilt=DtoR(40);
				if(pan>DtoR(80))
					pan=DtoR(80);
				if(pan<DtoR(-80))
					pan=DtoR(-80);
				HeadPointerMC * headpointer = (HeadPointerMC*)motman->checkoutMotion(headpointer_id);
				headpointer->setJoints(tilt/4,pan/2,0);
				motman->checkinMotion(headpointer_id);
			}
			else if(event.getSourceID() == 1111)
			{
				cout << " A:" << area1 << "\tH:" << horz1 << "\tV:" << vert1 << endl;
					if(see_time == cur_time)
					{
						MMAccessor<WalkMC> walk(walker_id);
						if(horz1 < -0.5) //to the left
						{
							cout << "On the left side" << endl;	
							walk.mc()->setTargetVelocity(0,120.0,-0.17,4);
						}
						else if(horz1 > -0.5 && horz1 < 0.5) //in the middle
						{
							cout << "In the middle" << endl;
							walk.mc()->setTargetVelocity(0,0,0,1);
						}
						else if(horz1 > 0.5) //to the right
						{
							cout << "On the right side" << endl;
							walk.mc()->setTargetVelocity(0,-120.0,0.15,4);
						}
					}
					cur_time += 0.500;
			}
			return;
		
		}


		//if none of the sensors were detected, then we must be playing:
		//determine which playing sub-state we are in and process accordingly
		//cout << "The current Sub State is: ";

		switch (subState)
		{
			case PLAY_PAUSED:
				cout << "PLAY_PAUSED" << endl;
				subState = PLAY_LOOK_FOR_BALL;
				break;
			case PLAY_PLAY:
				cout << "PLAY_PLAY" << endl;
				PrevAreaCounter =0;
				subState = PLAY_LOOK_FOR_BALL;
				time_in_state = 0;
				//this is an obsolete state
				break;
			case PLAY_LOOK_FOR_BALL:
				cout << "PLAY_LOOK_FOR_BALL" << endl;
				subState = PLAY_GO_TO_BALL;
				

				//old search stuff

				//move head and move body
				/*
				if (event.getSourceID()==ProjectInterface::visOrangeBallSID )
				{
						cout << "I see the ball" << endl;
						subState = PLAY_GO_TO_BALL;
						return;
				}

				if( time_in_state < 3)
				{
					//pan head first to look for ball
					SharedObject<MediumMotionSequenceMC>  p("/ms/data/motion/pan_head.mot");
					motman->addPrunableMotion(p);
				}
				else	//otherwise not found so turn body
				{
					if (time_in_state > 7)		//reset the timer after 5 seconds of turning (so that he will pan again
						time_in_state = 0;
					else
					{
						//else 360 until see ball
						cout << "Look for ball" << endl;
						WalkMC * walker = (WalkMC*)motman->checkoutMotion(walker_id);
						//walker->setTargetVelocity(12,100,39);//rotate pretty large circle with head in center		
						walker->setTargetVelocity(0,-29.9009, 0.684306);//rotate pretty large circle with head in center		
						motman->checkinMotion(walker_id);
					}
				}

				break;*/
			case PLAY_GO_TO_BALL:
				//call walking function
				//we see the ball, so lets go to it
				//stop when near ball (see distance) then set new state/mode

				//cout << "PLAY_GO_TO_BALL" << endl;
                
				//get the current distance from the IR sensor
				distance = state->sensors[ChestIRDistOffset];
				cout<< "distance: " << distance << endl;
				if(distance < 105.0)
				{
					subState = PLAY_NEAR_BALL;
					MMAccessor<WalkMC>(walker_id)->setTargetVelocity(0,0,0);
					HeadPointerMC * headpointer= (HeadPointerMC*)motman->checkoutMotion(headpointer_id);
					headpointer->setJoints(DtoR(-70),0,DtoR(35));					//make AIBO drop his head to try and trap the ball
					motman->checkinMotion(headpointer_id);
					time_in_state = 0;
					return;
				}
			

				if(event.getSourceID()==ProjectInterface::visPinkBallSID && event.getTypeID()==EventBase::statusETID) 
				{
					//in case the head isn't pointing straight forward, we'll straife
					x=180.0f*cos(state->outputs[HeadOffset+PanOffset]);
					y=120.0f*sin(state->outputs[HeadOffset+PanOffset]);
					z=-static_cast<const VisionObjectEvent*>(&event)->getCenterX();
					MMAccessor<WalkMC>(walker_id)->setTargetVelocity(x,y,z);
				}

				/*
				//if you still see the ball:
				if(event.getSourceID()==ProjectInterface::visOrangeBallSID ) 
				{
					//some vars to hold chasing ball data
					WMreg(chase_ball_behavior);
					WMvari_(float, horiz, 0, chase_ball_behavior);
					WMvari_(float, vert, 0, chase_ball_behavior);
					WMvari_(float, area, 0, chase_ball_behavior);

					//get info on ball
					horiz=static_cast<const VisionObjectEvent*>(&event)->getCenterX();
					cout << "horizontal: " << horiz << endl;
					vert=static_cast<const VisionObjectEvent*>(&event)->getCenterY();
					cout << "vertical: " << vert << endl;
					area=static_cast<const VisionObjectEvent*>(&event)->getArea ();
					cout << "Horizontal: " << horiz << "\tVertical: " << vert << "\tArea: " << area << endl;

					//set head to follow ball
					double tilt=state->outputs[HeadOffset+TiltOffset]-vert*M_PI/7;
					double pan=state->outputs[HeadOffset+PanOffset]-horiz*M_PI/6;
					if(tilt<DtoR(-30))
						tilt=DtoR(-30);
					if(tilt>DtoR(40))
						tilt=DtoR(40);
					if(pan>DtoR(80))
						pan=DtoR(80);
					if(pan<DtoR(-80))
						pan=DtoR(-80);
					HeadPointerMC * headpointer= (HeadPointerMC*)motman->checkoutMotion(headpointer_id);
					//limit so that dog does not look down on top of the ball
					if (tilt <= -.44) tilt = -.44;
					headpointer->setJoints(tilt,pan,0);
					motman->checkinMotion(headpointer_id);

					//if just starting or still farther from ball
					if ((area > desired_area) || (previous_area == 999) || (area >= previous_area))
					{
						//walk to ball
						//cout << "Previous Area" <<  previous_area << endl;
						if (area > desired_area && PrevAreaCounter == 3)
						{previous_area = area; 
						PrevAreaCounter = 0;
						}
						else if (PrevAreaCounter > 3)
						{
							PrevAreaCounter = 0;}
							else{PrevAreaCounter++;}
						AreaCounter = 0;
						
						WalkMC * walker = (WalkMC*)motman->checkoutMotion(walker_id);
						if(state->outputs[HeadOffset+PanOffset]<-.05 || state->outputs[HeadOffset+PanOffset]>.05)
							walker->setTargetVelocity(100,0,state->outputs[HeadOffset+PanOffset]);
						else
							walker->setTargetVelocity(160,0,0);
						
						motman->checkinMotion(walker_id);
					}
				
					else if (area <= desired_area && AreaCounter >= 3)  //else if we are close to the ball, change mode
					{
						WalkMC * walker = (WalkMC*)motman->checkoutMotion(walker_id);
						walker->setTargetVelocity(0,0,0);
						motman->checkinMotion(walker_id);
						cout << "Near Ball" << endl;
						subState=PLAY_NEAR_BALL;
						
					}
					else if (AreaCounter < 3)
					{
						AreaCounter++;
					}
				} //endif still see ball
				else
				{
					//ball lost
					subState = PLAY_LOOK_FOR_BALL;
				}
				*/
				break;
			case PLAY_NEAR_BALL:


				if(time_in_state >= 3)
				{

					//try and trap the ball
					HeadPointerMC * headpointer= (HeadPointerMC*)motman->checkoutMotion(headpointer_id);
					headpointer->setJoints(0,0,0);					//make AIBO drop his head to signify that he is penalized
					motman->checkinMotion(headpointer_id);
					motman->addPrunableMotion((SharedObject<MediumMotionSequenceMC>)("/ms/data/motion/k_bump.mot"));
			
					subState = PLAY_LOOK_FOR_BALL;
				}
				
/*

				//kick it (or look for goal first)

				cout << "PLAY_NEAR_BALL" << endl;
				float area;
				area=static_cast<const VisionObjectEvent*>(&event)->getArea ();
				cout << area << endl;
				
				motman->addPrunableMotion((SharedObject<MediumMotionSequenceMC>)("/ms/data/motion/k_bump.mot"));
				subState = PLAY_NEAR_BALL;
				return;
				//or rotate around ball until goal is seen

				if (event.getSourceID()==ProjectInterface::visYellowGoalSID && event.getGeneratorID()==EventBase::visObjEGID 
						&& event.getTypeID()==EventBase::statusETID)
				{
					//test for goal recognition
					//cout << "Area: " <<  area << "    Previous Area: " <<  previous_area << "    Desired Area: " << desired_area << endl;

					cout <<"GOAL IN VIEW" << endl;
					subState = PLAY_GET_INLINE;
				}*/
				break;
			case PLAY_FIND_GOAL:
				cout << "PLAY_FIND_GOAL" << endl;
				//look for the opposing goal (event only fired when ball is seen)
				if (event.getSourceID()==ProjectInterface::visYellowGoalSID && event.getGeneratorID()==EventBase::visObjEGID 
					&& event.getTypeID()==EventBase::statusETID)
				{
					cout<<"Look for Goal"<<endl;
					WalkMC * walker = (WalkMC*)motman->checkoutMotion(walker_id);
					walker->setTargetVelocity(-100,0,0);//rotate pretty large circle with head in center		
					motman->checkinMotion(walker_id);
					subState = PLAY_GET_INLINE;
				}
				break;
			case PLAY_GET_INLINE:
				cout << "PLAY_GET_INLINE" << endl;
				//
				break;

		};
				

		
	}

	else if (PENALIZED == currGState)
	{
		subState = PLAY_PAUSED;
		if (time_in_state %  5 == 0)    //temp fix to stop spam
		{
			cout << "The current state is PENALIZED" << endl;
		}

		if(event.getSourceID() == HeadFrButOffset)
		{
			cout << "Head button pressed!" << endl;

			if(event.getTypeID() == EventBase::activateETID)  //btn pressed
			{
				cout << "Button Pressed down" << endl;
				time_in_state = 0;			//start the timer over to measure how long btn pressed
				isBtnPressed = true;		//a slight hack to reuse the counter here
			}
			else if(event.getTypeID() == EventBase::deactivateETID && isBtnPressed == true)		//btn released
			{
				isBtnPressed = false;
				leds_mc->set(RobotInfo::ModeRedLEDMask, 0);
				if (time_in_state < 3)
				{
					//move to state playing (end of penalty)
					cout << "Head button pressed! @ Time: " << time_in_state << endl;
					currGState = PLAYING;
					subState = PLAY_LOOK_FOR_BALL;					//playing  set to play
					
					leds_mc->cycle(RobotInfo::ModeGreenLEDMask, 1000, 100.0); 
			
			
				}
				else
				{
					//move back to the initialize/ready state
					currGState = INITIAL;
					leds_mc->cycle(RobotInfo::ModeGreenLEDMask, 1000, 100.0);			//together these will make the ears blink Yellow
					leds_mc->cycle(RobotInfo::ModeRedLEDMask, 1000, 100.0);				//########################
					
				}
				HeadPointerMC * headpointer = (HeadPointerMC*)motman->checkoutMotion(headpointer_id);	//return head to normal view
				headpointer->setJoints(0,0,0);
				motman->checkinMotion(headpointer_id);


			}
			
			
			return;
		}

	}
	else
	{
		cout << "Unknown state.  Error!!" << endl;
	}

}

HRESULT SimpleSoccer::FindPosts(){
	//this is a function that will make AIBO look back and forth for any two goal posts
	//returns S_OK if found E_Fail if not found

	HRESULT RC = E_FAILED;

	SharedObject<MediumMotionSequenceMC>  p("/ms/data/motion/shakeHead.mot");
	motman->addPrunableMotion(p);
	//tilt = -75 deg -> 0 deg
	//pan = - 88 -> 88 deg
	//nod = -15 -> 45 deg
	RC = S_OK;

	return RC;


}
